<?php
/* constant strings
 * $Revision: 1.97.2.1 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XOONIPS_ADMIN", "XooNIps " );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS', '¸桼XooNIpsϿ' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_NON_XOONIPS_USER', 'XooNIps桼' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_XOONIPS_USER', 'XooNIps桼' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_ADD_TO_XOONIPS', 'ɲ -->' );
define( '_MD_XOONIPS_ADMIN_EDIT_DELETE_USER', '桼' );
define( '_MD_XOONIPS_ADMIN_EDIT_DELETE_USER_EXPLANATION', '桼ԽԤϡǽ˲桼ӡ˥桼򤷤Ƥ' );
define( '_MD_XOONIPS_ADMIN_ADD_USER_EXPLANATION', '桼ϡʲΥեɬפʾϤƤ' );

//module title for display
define( "_MD_XNPITEM", "ƥ" );

define( "_MD_XOONIPS_ITEM_LISTING_ITEM", "ƥ" );
define( "_MD_XOONIPS_ITEM_ORDER_BY", "¤ӽ : " );
define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM_PER_PAGE", "No.Item per page" );
define( "_MD_XOONIPS_ITEM_SELECT_ITEM_TYPE_LABEL", "ƥॿ" );
define( "_MD_XOONIPS_ITEM_ADD_ITEM_BUTTON_LABEL", "ƥɲ" );
define( "_MD_XOONIPS_ITEM_EDIT_INDEX_BUTTON_LABEL", "ǥåԽ" );
define( "_MD_XOONIPS_ITEM_SEARCH_RESULT", "" );
define( "_MD_XOONIPS_ITEM_SEARCH_KEYWORD", "" );
define( "_MD_XOONIPS_ITEM_SEARCH_ITEMTYPE", "о" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_ITEM", "ƥ" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_METADATA", "᥿ǡ" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_FILE", "ե" );
define( "_MI_XOONIPS_ITEM_NO_ITEM_LISTED", "ĥ꡼򳫤Ƥ˻ҥǥå֥饦ƤߤƲ" );

define( "_MD_XOONIPS_ITEM_DETAIL_ITEM_TITLE", "ܺ" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_TITLE", "Խ" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_CONFIRM", "Խ" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_CONFIRM_MESSAGE", "" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_TITLE", "Ͽ" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_CONFIRM", "Ͽ" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_CONFIRM_MESSAGE", "" );

define( "_MD_XOONIPS_ITEM_PRINT_FRIENDLY_BUTTON_LABEL", "" );
define( "_MD_XOONIPS_ITEM_UPDATE_BUTTON_LABEL", "" );
define( "_MD_XOONIPS_ITEM_DELETE_BUTTON_LABEL", "" );
define( "_MD_XOONIPS_ITEM_REGISTER_BUTTON_LABEL", "Ͽ" );
define( "_MD_XOONIPS_ITEM_MODIFY_BUTTON_LABEL", "Խ" );
define( "_MD_XOONIPS_ITEM_NEXT_BUTTON_LABEL", "" );
define( "_MD_XOONIPS_ITEM_BACK_BUTTON_LABEL", "" );

define( "_MD_XOONIPS_ITEM_CERTIFY_ITEM_TITLE", "ƥྵǧ" );
define( "_MD_XOONIPS_ITEM_CERTIFY_BUTTON_LABEL", "Accept" );
define( "_MD_XOONIPS_ITEM_UNCERTIFY_BUTTON_LABEL", "Reject" );
define( "_MD_XOONIPS_ITEM_WITHDRAW_BUTTON_LABEL", "Withdraw" );

define( "_MD_XOONIPS_ITEM_ITEM_LABEL", "ƥ" );
define( "_MD_XOONIPS_ITEM_INDEX_LABEL", "ǥå" );

define( "_MD_XOONIPS_ITEM_SELECT_BUTTON_LABEL", "" );
define( "_MD_XOONIPS_ITEM_SELECT_NONE_LABEL", "ʤ" );

define( "_MD_XOONIPS_ITEM_README_LABEL", "Readme" );
define( "_MD_XOONIPS_ITEM_LICENSE_LABEL", "License" );
define( "_MD_XOONIPS_ITEM_RIGHTS_LABEL", "Rights" );
define( "_MD_XOONIPS_ITEM_PREVIEW_LABEL", "ץӥ塼" );
define( "_MD_XOONIPS_ITEM_CAPTION_LABEL", "ץӥ塼Υץ" );
define( "_MD_XOONIPS_ITEM_ATTACHMENT_LABEL", "źեե" );
define( "_MD_XOONIPS_ITEM_TEXTFILE_LABEL", "ƥȥե" );
define( "_MD_XOONIPS_ITEM_FILE_HEAD_LABEL", "ե롧" );
define( "_MD_XOONIPS_ITEM_CAPTION_HEAD_LABEL", "ץ" );
define( "_MD_XOONIPS_ITEM_ORIGINAL_FILE_NAME_LABEL", "ե̾" );
define( "_MD_XOONIPS_ITEM_MIME_TYPE_LABEL", "Mime-type" );
define( "_MD_XOONIPS_ITEM_TYPE_LABEL", "Type" );
define( "_MD_XOONIPS_ITEM_SIZE_LABEL", "Size" );
define( "_MD_XOONIPS_ITEM_LAST_UPDATED_LABEL", "Last updated" );
define( "_MD_XOONIPS_ITEM_DOWNLOAD_LABEL", "Download" );

define( "_MD_XOONIPS_ITEM_TEXT_FILE_EDIT_LABEL", "Խ" );
define( "_MD_XOONIPS_ITEM_UPLOAD_LABEL", "" );
define( "_MD_XOONIPS_ITEM_OK_LABEL", "OK" );
define( "_MD_XOONIPS_ITEM_CANCEL_LABEL", "󥻥" );

define( "_MD_XOONIPS_ITEM_FROM_LABEL", "From" );
define( "_MD_XOONIPS_ITEM_TO_LABEL", "To" );

define( "_MD_XOONIPS_ITEM_TITLE_REQUIRED", "'ȥ' ϤƲ" );
define( "_MD_XOONIPS_ITEM_UPLOAD_PREVIEW", "Uploadܥ򲡤ơץӥ塼ե '%s' 򥢥åץɤƤ" );

define( "_MD_XOONIPS_ITEM_REQUIRED_MARK", "<font color=red>*</font>" );
define( "_MD_XOONIPS_ITEM_DOWNLOAD_CONFIRMATION", "ΥեΥ饤ʸ˹դޤ" );

define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "ΰɲ<br />" );
define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "ɲ" );

//Basic Information field name
define( "_MD_XOONIPS_ITEM_TITLE_LABEL", "ȥ" );
define( "_MD_XOONIPS_ITEM_KEYWORDS_LABEL", "ե꡼" );
define( "_MD_XOONIPS_ITEM_DESCRIPTION_LABEL", "" );
define( "_MD_XOONIPS_ITEM_DOI_LABEL", "ID" );
define( "_MD_XOONIPS_ITEM_ITEM_TYPE_LABEL", "ƥॿ" );
define( "_MD_XOONIPS_ITEM_CREATION_DATE_LABEL", "" );
define( "_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL", "ǽ" );
define( "_MD_XOONIPS_ITEM_CHANGELOG_LABEL", "ѹ" );
define( "_MD_XOONIPS_ITEM_CHANGELOGS_LABEL", "" );
define( "_MD_XOONIPS_ITEM_CONTRIBUTOR_LABEL", "Ͽ" );
define( "_MD_XOONIPS_ITEM_UID_LABEL", "ϿID" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL", "" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_YEAR_LABEL", "ǯ" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_MONTH_LABEL", "" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_MDAY_LABEL", "" );

define( "_MD_XOONIPS_ITEM_SELECT_INDEX", "ǥåĥ꡼饤ǥå򤷤Ʋ" );
define( "_MD_XOONIPS_ITEM_SELECT_PRIVATE_INDEX", "ʤȤ 1ĤΥץ饤١ȥǥåĥ꡼򤷤Ʋ" );
define( "_MD_XOONIPS_ITEM_NEED_TO_BE_CERTIFIED", "뤿ˤϥǥ졼⤷ϥ롼״ԤξǧɬפǤκȤˤϿפ礬ޤ" );
define( "_MD_XOONIPS_ITEM_FORBIDDEN"    ,"ΥꥢؤΥޤ" );
define( "_MD_XOONIPS_ITEM_CANNOT_ACCESS_ITEM"    ,"ΥƥؤΥޤ" );
define( "_MD_XOONIPS_ITEM_DELETE_CONFIRMATION_MESSAGE", "˺ƤǤ?" );
define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_CONFIRMATION_MESSAGE", "ˤΥƥǧƤǤ?" );
define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_CONFIRMATION_MESSAGE", "ˤΥƥѲƤǤ?" );
define( "_MD_XOONIPS_ITEM_WITHDRAW_CONFIRMATION_MESSAGE", "ˤΥƥѲƤǤ?" );

define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_SUBJECT", "Ͽ줿ƥ" );
define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_BODY", "" );

define( "_MD_XOONIPS_ITEM_DETAIL_URL", "ܺ٤URL" );
define( "_MD_XOONIPS_ITEM_ADVANCED_SEARCH_TITLE", "ƥม" );

define( "_MD_XOONIPS_ITEM_UPLOAD_FILE_TOO_LARGE", "åץɤե뤬礭ޤ");
define( "_MD_XOONIPS_ITEM_UPLOAD_FILE_FAILED", "ե򥢥åץɤǤޤ" );
define( "_MD_XOONIPS_ITEM_THUMBNAIL_BAD_FILETYPE", "̤бΥեǤͥ뤬Ǥޤ" );
define( "_MD_XOONIPS_ITEM_NO_CERTIFY_ITEMS", "ϿƥϤޤ" );
define( "_MD_XOONIPS_HEADER_CERTIFY_ITEMS", "ʲΥƥǧƲ" );

define( "_MD_XOONIPS_ITEM_WARNING_ITEM_NUMBER_LIMIT", "ʾ奢ƥϿǤޤ󡥥ȴԤϢƲ" );
define( "_MD_XOONIPS_ITEM_WARNING_INDEX_NUMBER_LIMIT", "ʾ奤ǥåϿǤޤ󡥥ȴԤϢƲ" );
define( "_MD_XOONIPS_ITEM_WARNING_ITEM_STORAGE_LIMIT", "ǥΰ褬­ޤ󡥤ʾ奢ƥϿǤޤ󡥥ȴԤϢƲ" );
define( "_MD_XOONIPS_ITEM_WARNING_FIELD_TRIM", "ʸ¤ΤᡢֻǼʬڤΤƤޤ" );

define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM", "ƥ" );
define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "źեե" );

define( "_MI_XOONIPS_ITEM_PANKUZU_ADVANCED_SEARCH", "ܺٸ" );
define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "ƥϿ" );
define( "_MD_XOONIPS_ITEM_SEARCH_BUTTON_LABEL", "" );

define( "_MI_XOONIPS_ITEM_PENDING_NOW", "(Pending)" );

define( "_MD_XOONIPS_ITEM_BAD_FILE", "ʥե" );
define( "_MD_XOONIPS_ITEM_BAD_FILE_TYPE", "ʥե" );
define( "_MD_XOONIPS_ITEM_CANNOT_CREATE_TMPFILE", "ƥݥեǤޤ" );
define( "_MD_XOONIPS_ITEM_CANNOT_CREATE_ZIP", "ZIPեǤޤ" );
define( "_MD_XOONIPS_ITEM_SEARCH_ERROR", "䤤碌˼Ԥޤ" );
define( "_MD_XOONIPS_ITEM_SEARCH_SYNTAX_ERROR", "ʸˡ˸꤬ޤ" );
define( "_MD_XOONIPS_ITEM_DELETE_NONPUBLIC_ITEM", "%dĤƥबΤǡХǤޤ󡥤ƥƥХޤ" );

define( "_MD_XOONIPS_ITEM_EMPTY_BINDER_SUBJECT", "ХΥƥब0Ĥˤʤޤ" );
define( "_MD_XOONIPS_ITEM_EMPTY_BINDER_BODY", "Х '%s' Υƥब0Ĥˤʤޤ.\n\nurl for detail: %s" );

define( '_MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_TEXT', '%s ѹ' );
define( '_MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_DELIMITER', ', ' );

//define( '_MD_XOONIPS_ITEM_ASCEND', '&darr;' );
//define( '_MD_XOONIPS_ITEM_DESCEND', '&uarr;' );
define( '_MD_XOONIPS_ITEM_ASCEND', '' );
define( '_MD_XOONIPS_ITEM_DESCEND', '' );

define( '_MD_XOONIPS_ITEM_RELATED_TO_ADD_ID', 'ɲäϢƥID1ԤˤĤҤȤϤƤ' );

define( '_MD_XOONIPS_ITEM_RELATED_TO_EDIT_ID', 'ϢƥΥåOFFˤƤ' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_LEAVE_IT', 'ϢĤ' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_ITEM_ID', 'ƥID' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_ITEM_SUMMARY', 'ƥγ' );
define( "_MD_XOONIPS_ITEM_RELATED_TO_LABEL", "Ϣƥ" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_ADD_ID_BUTTON_LABEL", "ƥõ(ɥ)" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_DESCRIPTION", "" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_CLOSE_LABEL", "ɥĤ" );

define( '_MD_XOONIPS_RIGHTS_SOME_RIGHTS_RESERVED', 'Some rights reserved' );
define( '_MD_XOONIPS_RIGHTS_ALL_RIGHTS_RESERVED', 'All rights reserved' );
define( '_MD_XOONIPS_RIGHTS_ALLOW_COMMERCIAL_USE', 'ʤκʤαŪѤޤ?' );
define( '_MD_XOONIPS_RIGHTS_ALLOW_MODIFICATIONS', 'ʤκʤݰơѤޤ?' );
define( '_MD_XOONIPS_RIGHTS_YES_SA', 'Ϥ¾ο͡ƱǶͭΤߡ' );

/// following defines for moderator 

define('_MD_XNP_BAD_CONFIG','XooNIps꤬۾Ǥxoops_xnp_configơ֥AL_PATHλ꤬ޤ');

define("_MD_XOONIPS_MODERATOR_SHULD_BE_MODERATOR"    ,"ΥꥢؤΥ¤ޤ󡥥ǥ졼¤ɬפˤʤޤ" );

// editgroups.php?op=
define('_MD_XOONIPS_MODERATOR_GROUP_LIST','롼װ');
define('_MD_XOONIPS_MODERATOR_GNAME','롼̾');
define('_MD_XOONIPS_MODERATOR_GDESC','롼׾ܺ');
define('_MD_XOONIPS_MODERATOR_ADMINISTRATOR','aministrator');
define('_MD_XOONIPS_MODERATOR_OPERATION','');
define('_MD_XOONIPS_MODERATOR_EDIT','Խ');
define('_MD_XOONIPS_MODERATOR_DELETE','');
define('_MD_XOONIPS_MODERATOR_GROUP_ADMIN','롼״');
define('_MD_XOONIPS_MODERATOR_CREATE_GROUP','롼׺');
define('_MD_XOONIPS_MODERATOR_EDIT_GROUP','롼Խ');
define('_MD_XOONIPS_MODERATOR_REALLY_DELETE' ,'Υ롼פޤ?' );
define('_MD_XOONIPS_MODERATOR_ITEM_STORAGE_LIMIT' ,'Ͽǽʥƥκǥ[MB]' );
define('_MD_XOONIPS_MODERATOR_ITEM_NUMBER_LIMIT' ,'ϿǽʥƥκĿ' );
define('_MD_XOONIPS_MODERATOR_INDEX_NUMBER_LIMIT' ,'ϿǽʥǥåκĿ' );

// certify.php
define('_MD_XOONIPS_MODERATOR_CERTIFY_USER','XooNIps 桼ǧ');
define('_MD_XOONIPS_MODERATOR_DETAIL','ܺ');
define('_MD_XOONIPS_MODERATOR_CERTIFY','ǧ');

define("_MD_XOONIPS_MODERATOR_ENTER_GROUP_NAME"    ,"롼̾ϤƤ" );
define("_MD_XOONIPS_MODERATOR_ERROR_INSERT_GROUP"    ,"롼פϿ˼Ԥޤ" );
define("_MD_XOONIPS_MODERATOR_ERROR_SELECT_GROUP"    ,"롼פμ˼Ԥޤ" );
define("_MD_XOONIPS_MODERATOR_ERROR_DELETE_GROUP"    ,"롼פκ˼Ԥޤ" );

define("_MD_XOONIPS_MODERATOR_NOT_ACTIVATED"    ,"ǧƤʤᥢǤޤ" );
define("_MD_XOONIPS_MODERATOR_NO_CERTIFY_USERS"    ,"ǧԤΥ桼Ϥޤ" );

define("_MI_XOONIPS_MODERATOR_PANKUZU_CERTIFY_USERS", "桼ǧ" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "롼Խ" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_LIST_GROUPS", "Group List" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "Create new group" );
define("_MD_XOONIPS_MODERATOR_MODIFY_ANY_ITEMS_TITLE", "ǥ졼桼ΥƥԽǤ" );

define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "Υ롼̾ϴ¸ߤޤ" );
define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "桼ǧޤ" );

/// following defines for index

define( "_MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL", "ץ饤١ȥǥå" );
define( "_MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL", "롼ץǥå" );
define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "ϿǽʥǥåĶᡢǥåǤޤ" );
define( "_MD_XOONIPS_INDEX_NO_INDEX", "֥ǥåɤϤޤ" );

define( "_MD_XOONIPS_INDEX_BUTTON_REGISTER", "Ͽ");// 
define( "_MD_XOONIPS_INDEX_TITLE_EDIT", "ǥåԽ");// 
define( "_MD_XOONIPS_INDEX_TITLE_ADD", "ɲ");// 
define( "_MD_XOONIPS_INDEX_TITLE_NEW_INDEX_KEYWORD", "New Index Keyword");// 
define( "_MD_XOONIPS_INDEX_TITLE_MODIFY", "Խ");// 
define( "_MD_XOONIPS_INDEX_INDEX_KEYWORD", "ǥå");// 
define( "_MD_XOONIPS_INDEX_RENAME_TO", "Rename to");// 
define( "_MD_XOONIPS_INDEX_LABEL_UPDOWN", "/");// 
define( "_MD_XOONIPS_INDEX_LABEL_UP", "");// 
define( "_MD_XOONIPS_INDEX_LABEL_DOWN", "");// 
define( "_MD_XOONIPS_INDEX_BUTTON_RENAME", "̾");// 
define( "_MD_XOONIPS_INDEX_BUTTON_DELETE", "");// 
define( "_MD_XOONIPS_INDEX_BUTTON_MOVETO", "ذư : ");// 
define( "_MD_XOONIPS_INDEX_LABEL_WITH_SELECTED", "With selected:");// 

define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_PUBLIC_INDEX_KEYWORD", "ĥ꡼Խ");// 
define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_GROUP_INDEX_KEYWORD", "롼ץĥ꡼Խ");// 
define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_PRIVATE_INDEX_KEYWORD", "ץ饤١ȥĥ꡼Խ");// 
define( "_MD_XOONIPS_INDEX_NAME_CANNOT_BE_EMPTY", "ǥåɤǤ");//
define( "_MD_XOONIPS_INDEX_DESTINATION_HAS_TOO_MANY_INDEXES", "顼: Υǥåϥǥå¿ޤ");//

define( "_MD_XOONIPS_INDEX_RENAME_MESSAGE", "ǥåɤ̾ %s  %s ѹޤȼΥƥˤƶޤ :");//
define( "_MD_XOONIPS_INDEX_RENAME_MAIL_SUBJECT", "ǥåɤ̾ѹޤ" );
define( "_MD_XOONIPS_INDEX_DELETE_MESSAGE", "ǥå %s ޤȼΥƥˤƶޤ :");//
define( "_MD_XOONIPS_INDEX_DELETE_MAIL_SUBJECT", "ǥåɤޤ" );
define( "_MD_XOONIPS_INDEX_MOVETO_MESSAGE", "ǥå %s  %s ذưޤȼΥƥƶޤ :");//
define( "_MD_XOONIPS_INDEX_MOVETO_MAIL_SUBJECT", "ǥåɤϰưޤ" );
define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "ǥå̾ '%s' 礷Ƥޤ" );
define( "_MD_XOONIPS_INDEX_TITLE_EXCEEDS", "ǥå̾Ĺޤ" );
define( "_MD_XOONIPS_INDEX_TITLE_EMPTY", "ǥå̾ˤ뤳ȤϤǤޤ" );
define( "_MD_XOONIPS_INDEX_FORBIDDEN", "̤Ͽ桼ʤΤǥǥåĥ꡼ɽǤޤ" );

// following defines for configuration

define("_MD_XOONIPS_CONFIG_CONFIG", "XooNIps ");// 

define("_MD_XOONIPS_CONFIG_CONFIG_TEST_LABEL", "ƥ");// 
define("_MD_XOONIPS_CONFIG_RESULT_LABEL", "ƥȷ");// 
define("_MD_XOONIPS_CONFIG_TEST_AGAIN_LABEL", "ƥƥ");// 

define("_MD_XOONIPS_CONFIG_SUCCEEDED", "");//
define("_MD_XOONIPS_CONFIG_FAILED",    "");//

define("_MD_XOONIPS_CONFIG_ENABLED",   "ͭ");//
define("_MD_XOONIPS_CONFIG_DISABLED",  "̵");//

define("_MD_XOONIPS_CONFIG_SKIPED",    "å");//

define("_MD_XOONIPS_CONFIG_TEST_L1", "ODBC DSN : ");//
define("_MD_XOONIPS_CONFIG_TEST_L1_NG", "(ꤵƤޤ)");//
define("_MD_XOONIPS_CONFIG_TEST_L2", "dl() - ưŪ⥸塼ɤ߹ : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L3", "PHP Unified ODBC ؿ : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L4", "odbc_connect() ˤ Abstract Layer ³ƥ : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L5", "PHP XooNIps Abstract Layer ؿ : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L6", "Abstract Layer ν : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L7", "ƥȷ : ");// 

define("_MD_XOONIPS_INDEX_TF_WIDTH", "ǥåĥ꡼֥å");
define("_MD_XOONIPS_INDEX_TF_HEIGHT", "ǥåĥ꡼֥åι⤵");
define("_MD_XOONIPS_PRINT_HEADER", "ڡΤإå");


/// following defines for binder

define( '_MD_XOONIPS_BINDER_ITEMS_TO_REGISTER_TITLE', 'ƥϿޤ' );
define( '_MI_XOONIPS_BINDER_DELETE_CHECKED_ITEM_BUTTON_LABEL', 'å줿ƥޤ' );
define( '_MD_XOONIPS_BINDER_REGISTERED_ITEMS_TITLE', 'ϿѤߥƥ' );
define( '_MI_XOONIPS_BINDER_ADD_FROM_ITEM_LIST_BUTTON_LABEL', 'ƥ' );
define( '_MI_XOONIPS_BINDER_ADD_FROM_COLUMN_LABEL', "饢ƥɲ : " );
define( '_MI_XOONIPS_BINDER_ADD_FROM_INDEX_BUTTON_LABEL', "ǥå" );
define( '_MI_XOONIPS_BINDER_ADD_FROM_SEARCH_BUTTON_LABEL', "" );

define( '_MD_XOONIPS_BINDER_ITEM_REQUIRED', 'ʤȤ1İʾΥƥबɬפǤ' );
define( '_MD_XOONIPS_BINDER_ITEM_LABEL', "ƥ" );

/// following defines for account

//module title for display
define("_MD_XNPACCOUNT", "XooNIps 桼");

// admin/index.php
define("_MD_XOONIPS_ACCOUNT_ADMIN", "XooNIps 桼");
define("_MD_XOONIPS_ACCOUNT_ADMIN_USERS", "桼");

// error labels
define('_MD_XOONIPS_ACCOUNT_BAD_CONFIG','XooNIps ꤬۾Ǥxoops_xnp_config ơ֥ AL_PATH λ꤬ޤ');
define('_MD_XOONIPS_ACCOUNT_CANNOT_INITIALIZE_AL','Abstract Layer ν˼Ԥޤ');
define('_MD_XOONIPS_ACCOUNT_DSN_EMPTY','xoonips  dsn ꤵƤޤ');

//labels of register/edit account items
define("_MD_XOONIPS_ACCOUNT_ADDRESS", "" );
define("_MD_XOONIPS_ACCOUNT_DIVISION", "°" );
define("_MD_XOONIPS_ACCOUNT_TEL", "ֹ" );
define("_MD_XOONIPS_ACCOUNT_FAX", "FAXֹ" );
define("_MD_XOONIPS_ACCOUNT_COMPANY_NAME", "̾/̾/̾" );
define("_MD_XOONIPS_ACCOUNT_COUNTRY", "̾" );
define("_MD_XOONIPS_ACCOUNT_ZIPCODE", "͹ֹ" );
define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL", "᡼ֳ []" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT",  "ץ饤١ȥƥκϿ" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT", "ץ饤١ȥǥåκϿ" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT", "ץ饤١ȥƥκǥ [MB]" );
define("_MD_XOONIPS_ACCOUNT_POSITION", "̾" );
define("_MD_XOONIPS_ACCOUNT_NSRA", "̾ꤵƤޤ" );
define("_MD_XOONIPS_ACCOUNT_NSRID", "꤬̾ޤ" );
define("_MD_XOONIPS_ACCOUNT_APPEAL", "ͳ" );
define("_MD_XOONIPS_ACCOUNT_CVITAE", "ά" );

define("_MD_XOONIPS_ACCOUNT_XNP_USER_INFO", "桼" );

define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL_TOO_LITTLE", "᡼ֳ֤ˤ 0ʾοͤꤷƤ" );
define("_MD_XOONIPS_ACCOUNT_INVALID_SECRETKEY", "ʥåȥǤ" );
define("_MD_XOONIPS_ACCOUNT_PUSH_BUTTON_TO_ENTER_USERINFO", "ܥ򲡤Ƥ桼Ͽ̤ؿʤߤޤ");
define("_MD_XOONIPS_ACCOUNT_INVITATION_SUCCED", "Ҳ𤢤꤬Ȥޤ" );
define("_MD_XOONIPS_ACCOUNT_NOTREGISTERED1", "<a href='registeruser.php'>Ͽ</a>ޤ󤫡" );
define("_MD_XOONIPS_ACCOUNT_NOTREGISTERED2", "" );

// register.php errormessage
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ADDRESS"     ,""                           . "Ĺޤ127ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_DIVISION"    ,"°"                          . "Ĺޤ127ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_TEL"         ,"ֹ"                          . "ĹޤȾ32ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COMPANY_NAME","FAXֹ"                            . "ĹޤȾ32ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ZIPCODE"     ,"͹ֹ"                          . "Ĺޤ127ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COUNTRY"     ,"̾/̾/̾" . "Ĺޤ127ʸʲˤƲ");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_FAX"         ,"̾"                           . "ĹޤȾ32ʸʲˤƤ");
define("_MD_XOONIPS_ACCOUNT_MUST_BE_FILLED_IN", "'%s' ϤƤ" );

define("_MD_XOONIPS_ACCOUNT_INVITE_USER"    ,"桼Ҳ" );
define("_MD_XOONIPS_ACCOUNT_INVITE_USER_MAIL_SUBJECT"    ,"ҲΤΤ餻 " );

// useradmin.php
define("_MD_XOONIPS_ACCOUNT_CANNOT_ACQUIRE_USER_INFO", "桼μ˼Ԥޤ" );
define("_MD_XOONIPS_ACCOUNT_CANNOT_UPDATE_USER_INFO" , "桼ι˼Ԥޤ" );

// groupadmin.php
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN"                 ,"롼״");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_GROUP_LIST"      ,"롼װ");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_MEMBERS"         ,"С");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NON_MEMBERS"     ,"С");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_ADD_BUTTON"      ,"ɲ -->");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_DELETE_BUTTON"   ,"<-- ");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NO_EDITABLE_GROUPS"        ,"ǽʥ롼פϤޤ");

define("_MD_XOONIPS_ACCOUNT_QUERY_ERROR"    ,"ǡ١Υꥨ顼Ǥ" );

define("_MD_XOONIPS_ACCOUNT_FORBIDDEN"    ,"ΥꥢؤΥϵĤƤޤ" );

define( "_MD_XOONIPS_ACCOUNT_SELECT_USER", "桼" );
define( "_MD_XOONIPS_ACCOUNT_DELETE_USER", "桼" );
define( "_MD_XOONIPS_ACCOUNT_PASSWORD_DOESNT_MATCH", "ѥɤפޤ" );

define( "_MD_XOONIPS_ACCOUNT_PREFERENCE", "" );

// 
// mesasge for user registration
// 
define("_MD_XOONIPS_ACTIVATE_KEY_SUBJECT", '%sΥƥ١ȥǤ' );
define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_MANUAL", 'Ͽ᡼륢ɥ쥹˥ƥ١ȥޤ᡼λؼˤäƥȤ򥢥ƥ١ȤƤƥ١Ȥϡǥ졼ˤ뾵ǧԤ' );
define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_AUTO", 'Ͽ᡼륢ɥ쥹˥ƥ١ȥޤ᡼λؼˤäƥȤ򥢥ƥ١ȤƤ' );
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL", 'ǥ졼إȤξǧޤǥ졼ξǧԤǧλˤϥ᡼ˤƤΤ餻ޤ' );
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL_MAILNG", 'Ȥξǧ᡼ǥ졼ǤޤǤԤӥǥ졼䤤碌Ƥ');
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_AUTO", 'ȤξǧλޤϿϤ桼̾ȥѥɤǥ󤷤Ƥ');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_CERTIFY_AUTO", 'ϿλޤȴԤΥƥ١ȤԤƥ١ȴλˤϥ᡼ˤƤΤ餻ޤ');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_CERTIFY_MANUAL", 'ϿλޤȴԤΥƥ١Ȥȡǥ졼ξǧԤǧλˤϥ᡼ˤƤΤ餻ޤ');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_MAILNG", 'ȴԤ˥ƥ١Ȥ׵᡼ǤޤǤȴԤ䤤碌Ƥ' );

define("_MD_XOONIPS_ACTIVATED_BY_USER_CERTIFIED_AUTO", 'ȤǧޤϿΥ桼̾ȥѥɤǥ󤷤Ƥ');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO", 'Ȥ򥢥ƥ١ȤޤϿΥ᡼륢ɥ쥹Υ᡼ޤ');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO_MAILNG", 'Ȥ򥢥ƥ١ȤޤϿΥ᡼륢ɥ쥹Υ᡼ǤޤǤ');
define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL", 'Ȥ򥢥ƥ١ȤޤȤǥ졼˾ǧޤǤԤ');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL", 'Ȥ򥢥ƥ١Ȥޤǥ졼Ⱦǧ塢Ͽ᡼륢ɥ쥹Τޤ');
define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL_MAILNG", 'Ȥξǧ᡼ǥ졼ǤޤǤԤӥǥ졼䤤碌Ƥ');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL_MAILNG", 'Ȥξǧ᡼ǥ졼ǤޤǤ');

define("_MD_XOONIPS_ACCOUNT_NOT_ACTIVATED", 'ǥ졼ξǧλƤʤᡢXooNIpsѤǤޤ󡣥ǥ졼ξǧԤǧλˤϥ᡼ˤƤΤ餻ޤ' );
define("_MD_XOONIPS_USER_ACTIVATED", 'Ȥϥƥ١Ȥޤǥ졼ˤ뾵ǧԤ');
define("_MD_XOONIPS_USER_NOACTTPADM", 'ȤΥƥ١ȡޤϥǥ졼ξǧλƤʤᡢXooNIpsѤǤޤ');
define("_MD_XOONIPS_ACCOUNT_ALREADY_CERTIFIED", "˾ǧƤޤ" );
define("_MD_XOONIPS_ACCOUNT_ACTIVATE_NG", "Ȥ򥢥ƥ١ȤǤޤǤԤӥǥ졼䤤碌Ƥ" );

//subjects for e-mail of user registration
define("_MD_XOONIPS_ACCOUNT_CERTIFIED", 'Ȥξǧλޤ' );
define('_MD_XOONIPS_ACCOUNT_REGISTERD','桼ǧƤ');


// admin/config.php
define("_MD_XOONIPS_ACCOUNT_CONFIG", "ư");
define("_MD_XOONIPS_ACCOUNT_MODERATOR_GROUP_TITLE", "ǥ졼롼");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_TITLE", "Ⱦǧ");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_DESC", "");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_AUTO", "ư");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_ON", "ư(׿)");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_TITLE", "ƥྵǧ");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_DESC", "");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_AUTO", "ư");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_ON", "ư(׿)");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_OFF", "ػ");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_TITLE", "ƥαݥꥷ");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_DESC", "");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_PLATFORM", "XooNIps Ͽ桼Τ");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_ALL", "(ȥ桼ޤ)");
define("_MD_XOONIPS_ACCOUNT_UPLOAD_DIR_TITLE", "åץɥեǼǥ쥯ȥ");
define("_MD_XOONIPS_ACCOUNT_REALNAME_OPTIONAL_TITLE" , '̾'  . '' );
define("_MD_XOONIPS_ACCOUNT_ADDRESS_OPTIONAL_TITLE" , ''  . '' );
define("_MD_XOONIPS_ACCOUNT_DIVISION_OPTIONAL_TITLE", '°' . '' );
define("_MD_XOONIPS_ACCOUNT_TEL_OPTIONAL_TITLE"     , 'žֹ'      . '' );
define("_MD_XOONIPS_ACCOUNT_COMPANY_OPTIONAL_TITLE" , '̾'  . '' );
define("_MD_XOONIPS_ACCOUNT_COUNTRY_OPTIONAL_TITLE" , '̾'  . '' );
define("_MD_XOONIPS_ACCOUNT_ZIPCODE_OPTIONAL_TITLE" , '͹ֹ'  . '' );
define("_MD_XOONIPS_ACCOUNT_FAX_OPTIONAL_TITLE"     , 'FAXֹ'      . '' );

define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , 'ĿΰϿǽʥƥκ' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , 'ĿΰϿǽʥǥåκ' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , 'ĿΰѲǽʥǥ̤κ [MB]' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , '롼ΰϿǽʥƥκ' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , '롼ΰϿǽʥǥåκ' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , '롼ΰѲǽʥǥ̤κ [MB]' );

define("_MD_XOONIPS_ACCOUNT_AMAZON_ASSOCIATES_ID_TITLE"   , 'AmazonID' );

define("_MD_XOONIPS_ACCOUNT_OPTIONAL"     , 'Ǥ'     );
define("_MD_XOONIPS_ACCOUNT_REQUIRED"     , 'ɬ'     );

define( "_MD_XOONIPS_ACCOUNT_REQUIRED_MARK", "(*)" );
define( "_MD_XOONIPS_ACCOUNT_EXPLAIN_REQUIRED_MARK", "(*) = ɬ" );

define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search,Start SU,End SU' );
define( '_MI_XOONIPS_EVENT_LOG_EVENT_COLUMNS','Event Type,Timestamp,Exec UID,Remote Host,Index ID,Item ID,File ID,UID,GID,Search Keyword,Login Name,Additional Information' );
define( "_MD_XOONIPS_EVENT_LOG_00", "" );
define( "_MD_XOONIPS_EVENT_LOG_10", "" );
define( "_MD_XOONIPS_EVENT_LOG_11", "ǯ" );
define( "_MD_XOONIPS_EVENT_LOG_12", "" );
define( "_MD_XOONIPS_EVENT_LOG_13", "  " );
define( "_MD_XOONIPS_EVENT_LOG_20", "" );
define( "_MD_XOONIPS_EVENT_LOG_21", "ǯ" );
define( "_MD_XOONIPS_EVENT_LOG_22", "" );
define( "_MD_XOONIPS_EVENT_LOG_23", "" );
define( "_MD_XOONIPS_EVENT_LOG_30", "Υ٥ȥ" );
define( "_MD_XOONIPS_EVENT_LOG_DOWNLOAD", "Download" );

//pankuzu
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_PLATFORM_USER', 'XooNIps 桼' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_GROUP_ADMINISTRATOR', '롼״' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_MODERATOR', 'ǥ졼' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_SEPARATOR', '&nbsp;&raquo;&raquo;&nbsp;' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_EDIT_GROUPS', '롼Խ' );
define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_PUBLIC_ITEMS', 'ƥྵǧ' );
define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', '롼׸ƥྵǧ' );
define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'ץեԽ' );
define( '_MI_XOONIPS_ITEM_PANKUZU_VIEW_ACCOUNT', 'Ⱦ' );
define( "_MI_XOONIPS_EVENT_LOG_PANKUZU", "٥ȥ" );
define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_CURRICULUM_VITAE', 'άԽ' );

//export/import
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT', 'ݡ' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_CONFIG', 'ݡ' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_LICENSE', 'ѵ(饤)' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_INDEX', 'ǥå򥨥ݡ' );
define( '_MD_XOONIPS_EXPORT_CONFIG_TITLE', 'ݡ' );
define( '_MD_XOONIPS_EXPORT_CONFIG_SUBMIT', '' );
define( '_MD_XOONIPS_EXPORT_RECURSIVE', 'ǥåƵŪ˥ݡȤ' );
define( '_MD_XOONIPS_EXPORT_ENABLED', 'Export' );
define( '_MD_XOONIPS_EXPORT_ATTACHMENT', 'źեե򥨥ݡȤ' );
define( '_MD_XOONIPS_PRIVATE_IMPORT_ENABLED', 'Import(XooNIps桼)' );
define( '_MD_XOONIPS_EXPORT_BUTTON_LABEL', 'ݡ' );
define( '_MD_XOONIPS_EXPORT_EXPORT_LICENSE', 'ѵ(饤)' );
define( '_MD_XOONIPS_EXPORT_LICENSE', '饤' );
define( '_MD_XOONIPS_EXPORT_ACCEPT', 'դ' );
define( '_MD_XOONIPS_EXPORT_CANNOT_BE_EXPORTED_ITEMS', 'ʲΥƥϥݡȤǤޤ' );
define( '_MD_XOONIPS_EXPORT_NO_ITEMS_FOUND', '륢ƥϤޤ' );
define( '_MD_XOONIPS_EXPORT_ACCEPT_ALL', '٤ƤΥ饤󥹤˹դ' );
define( '_MD_XOONIPS_EXPORT_EXPORT_ITEMS_EMPTY', 'Export륢ƥब򤵤Ƥޤ' );
define( '_MD_XOONIPS_EXPORT_LICENSE_AGREEMENT_SUBMIT', '' );
define( '_MD_XOONIPS_EXPORT_EXPORT_INDEX', 'ʲǥǥå򥨥ݡȤޤ' );
define( '_MD_XOONIPS_EXPORT_TYPE_ITEM', 'ƥ򥨥ݡȤ' );
define( '_MD_XOONIPS_EXPORT_TYPE_INDEX', 'ǥåĥ꡼򥨥ݡȤ' );
define( '_MD_XOONIPS_IMPORT_TITLE', 'ݡ' );
define( '_MD_XOONIPS_IMPORT_FILE', 'Importե' );
define( '_MD_XOONIPS_IMPORT_INDEX', 'Import襤ǥå' );
define( '_MD_XOONIPS_IMPORT_INDEX_TEXT', 'Importǥå򥤥ǥåĥ꡼򤷤Ƥ' );
define( '_MD_XOONIPS_IMPORT_REQUIRED', '(ɬ)' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_IMPORT', 'ݡ' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_RESOLVE_CONFLICT', 'ͤβ' );
define( '_MD_XOONIPS_IMPORT_TITLE_RESOLVE_CONFLICT', 'ͤβ' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ALL', 'ƥݡ' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ITEM', 'ݡȤ륢ƥ' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_UPLOAD_FILE', 'ե륢åץ' );
define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'ݡȤλޤ' );
define( '_MD_XOONIPS_IMPORT_NO_ITEMS_IMPORTED', 'ݡȤ륢ƥबޤ' );
define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'ʾ奤ǥå򥤥ݡȤǤޤ󡥥ȴԤϢƲ' );
define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'ʾ奢ƥ򥤥ݡȤǤޤ󡥥ȴԤϢƲ' );
define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', '' );
define( '_MD_XOONIPS_IMPORT_UPLOAD_SUBMIT', '' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_CHECK_LENGTH', 'ʸĶΥå' );
define( '_MD_XOONIPS_IMPORT_TITLE_CHECK_LENGTH', 'ʸĶΥå' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_SUBMIT', 'åץ' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_WARNING', 'ʲΥƥϡʸĶΤڤΤƤޤ(ֻʬ)' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_NO_WARNING', 'ʸĶ᤹륢ƥϤޤ' );
define( '_MD_XOONIPS_IMPORT_INDEX_CANNOT_WRITE', 'ʲΥǥå̵뤵ޤݡȤǤ륤ǥåϤʤΥץ饤١ȥǥåΤߤǤ' );
define( '_MD_XOONIPS_IMPORT_IGNORE_CHECK', 'ͤʸĶåʤ' );
define( '_MD_XOONIPS_IMPORT_NO_STRINGS_ARE_TRIMMED', 'ʸ¤ۤʸϤޤǤ' );
define( '_MD_XOONIPS_IMPORT_NO_CONFLICT_ITEMS', 'ͤ륢ƥϤޤǤ' );
define( '_MD_XOONIPS_IMPORT_NUMBER_OF_CONFLICT_ITEMS', 'ͤ륢ƥο' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', 'ʲΥƥबʣƤޤ' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ALL_AS_NEW', "ͤƤΥƥ򿷤ƥȤƥݡȤ\nʾ񤭥åܥåλ̵뤷ޤˡ" );
define( '_MD_XOONIPS_IMPORT_IMPORT_MODIFY', 'ݡ襤ǥåˤʲξͥƥ񤭤' );
define( '_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_IN_OTHER_INDEXES', '̤Υǥå˰ʲξͥƥबޤ(񤭤ޤ)' );
define( '_MD_XOONIPS_CONFLICT_ITEMS_IN_THE_SAME_FILE', 'ݡȥե˰ʲξͥƥबޤ' );
define( '_MD_XOONIPS_IMPORT_IMPORT_CAN_NOT_MODIFY', 'ʣΥƥȾͤΤǥݡȤǤޤ' );
define( '_MD_XOONIPS_IMPORT_LOGGING', 'Ϥ' );
define( '_MD_XOONIPS_IMPORT_ERROR', 'ݡȽ˥顼ȯޤ' );
define( '_MD_XOONIPS_IMPORT_READY', 'ݡȤǤޤ' );
define( '_MD_XOONIPS_IMPORT_NO_ERROR', '顼Ϥޤ' );
define( '_MD_XOONIPS_IMPORT_REVIEW_LOG', 'ǧƤ' );
define( '_MD_XOONIPS_IMPORT_LOCAL_FILE', 'ե򥤥ݡȤ' );
define( '_MD_XOONIPS_IMPORT_REMOTE_FILE', 'оΥե򥤥ݡȤ' );
define( '_MD_XOONIPS_IMPORT_ERROR_CHECK_ONLY', '顼åԤ' );
define( '_MD_XOONIPS_IMPORT_CONTRIBUTOR_SELECT', '桼θ¤ǥݡȤ' );
define( '_MD_XOONIPS_IMPORT_ERROR_CKECK_DONE', '顼åλޤ' );
define( '_MD_XOONIPS_IMPORT_INDEX_TREE_CREATED', 'ʲΥǥåĥ꡼򥤥ݡȤޤʥꥹδ¸Ʊ̾ǥåƤѹƤޤˡ' );
define( '_MD_XOONIPS_IMPORT_INDEX_TREE_FAILED', 'ǥåĥ꡼ΥݡȤ˼Ԥޤ' );
define( '_MD_XOONIPS_IMPORT_FILE_NOT_FOUND', 'ݡȥե뤬Ĥޤ' );
define( '_MD_XOONIPS_IMPORT_FILE_NOT_SPECIFIED', 'ݡȥե뤬ꤵƤޤ' );
define( '_MD_XOONIPS_IMPORT_CERTIFY_AUTO', 'ǥåϿ륢ƥưǧ' );
define( '_MD_XOONIPS_IMPORT_NO_ITEMS_ARE_FOUND', 'ݡȤ륢ƥबĤޤǤݡȥեƤǧƤ' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX', 'ʲΥǥå򥤥ݡȤޤ' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX_TEST', 'ʲΥǥå򥤥ݡȤǤޤ' );
define( '_MD_XOONIPS_IMPORT_CIRCULAR_INDEX', 'ǥå۴Ĺ¤äƤ뤿ᡢݡȤǤޤ' );

define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE', 'RSSΥեѥ' );
define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_NOT_WRITABLE_ERROR', '񤭹ߤǤޤ'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'ǧƤ' );
define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_PARENT_DIR_ERROR', 'ƥǥ쥯ȥؤΥ϶ػߤƤޤ'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'ǧƤ' );
define( '_MD_XOONIPS_ACCOUNT_DEFAULT_RSS_ITEM_MAX_TITLE', 'RSS˴ޤ祢ƥ(0ʾ)' );

define( '_MD_XOONIPS_EVENT_ITEM_IS_SHOWN_IN', 'ƥबʲΥǥå˸ޤ' );
define( '_MD_XOONIPS_EVENT_NEW_GROUP', '롼פޤ' );

define( '_MD_XOONIPS_ITEM_LANG_LABEL', '' );
define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor' );
define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', 'Ѹ,ܸ,ե󥹸,ɥĸ,ڥ,ꥢ,,ǥ,Υ륦,ǥޡ,եɸ,ݥȥ,,ڹ' );


define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', '' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION', 'ɥե륪ץ' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_YES', '᥿ǡZIPʿ侩' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_NO' , '̤ʤ' );
define( '_MD_XOONIPS_DOWNLOAD_ABNORMAL_CONFIGURATION' , 'ɥե륪ץΰ۾' );

define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_LOGINUSER_LABEL', '桼' );
define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_EVERYONE_LABEL', 'ƤΥ桼' );
define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_LOGINUSER_ONLY_LABEL', '桼Τ' );

define( '_MD_XOONIPS_REPOSITORY_NAME_TITLE', 'ݥȥ̾' );
define( '_MD_XOONIPS_REPOSITORY_NIJC_CODE_TITLE', 'ǡ١IDNIJCɡ' );
define( '_MD_XOONIPS_REPOSITORY_DELETION_TRACK_TITLE', 'ƥκ֤¸' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_TITLE', '&lt;institution&gt;' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_META_AUTHOR', 'Meta Author' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_CREATOR', 'ƥϿ' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_NONE', 'Ѥʤ' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_TITLE', '&lt;publisher&gt;' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_META_AUTHOR', 'Meta Author' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_CREATOR', 'ƥϿ' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_NONE', 'Ѥʤ' );

//admin/oaipmh.php
define( '_MD_XOONIPS_OAIPMH_CONFIG', 'OAI-PMH' );
define( '_MD_XOONIPS_OAIPMH_CONFIG_REPOSITORIES', 'ϡ٥ȤݥȥURL(ݥȥꤴȤ˲)' );
define( '_MD_XOONIPS_OAIPMH_CONFIG_LOGS', 'Ǹ˥ϡ٥ȤȤη(ιܤԽǤޤ)' );
define( '_MD_XOONIPS_OAIPMH_HARVESTING', 'ϡ٥Ȥ' );
define( '_MD_XOONIPS_OAIPMH_HARVESTING_EXPLAIN', 'ޤϡ٥ȤˤϤΥܥ򲡤Ƥ' );
define( '_MD_XOONIPS_OAIPMH_HARVEST_RESULT', 'ϡ٥ȷ' );
define( '_MD_XOONIPS_BACK_TO_OAIPMH_CONFIGURATION', _MD_XOONIPS_OAIPMH_CONFIG.'' );

define( '_MD_XOONIPS_METADATA_SEARCH_LABEL', '᥿ǡ' );

define( '_MD_XOONIPS_FILESEARCH', 'ե븡' );
define( '_MD_XOONIPS_FILESEARCH_NAME', '⥸塼̾' );
define( '_MD_XOONIPS_FILESEARCH_VERSION', 'С' );
define( '_MD_XOONIPS_FILESEARCH_RESCAN', 'ƤΥեƥ' );

// labels for item_show (edit)
define( '_MD_XOONIPS_ITEMSHOW_CURRICULUM_VITAE', 'ά' );
define( '_MD_XOONIPS_ITEM_SHOW_OPTIONAL_TITLE', 'ΰˤƤΥƥफӥƥ򤹤<br />ʤ桼ܿͤϿƥफǽ' );
define( '_MD_XOONIPS_ITEM_SHOW_EDIT_TITLE', 'ӥƥ' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_PREV', '' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_NEXT', '' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_CHECK', 'å' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_ITEMS', 'ƥ' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_SUBMIT', 'ѹ' );
define( '_MD_XOONIPS_NEED_LOGIN', '󤹤ȶӤαǤޤ' );

// admin/posi_order.php
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_TITLE', '̾ɽ' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_EXPLAIN', 'ɽ̤ͤʤ餽ο̾ϲ̤ɽޤ' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_POSI_LABEL', '̾' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_ORDER_LABEL', 'ɽ' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_CHECK_LABEL', 'å' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_TITLE', '̾ɲåե' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_EXPLAIN', 'ɽ礬ʤ飰ꤷޤ' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_LABEL', '̾ɲ' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSITITLE_LABEL', '̾' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSIORDER_LABEL', 'ɽ' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_TITLE', '桼ɽ' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_EXPLAIN', 'ɽ̤ͤʤ餽Υ桼ϲ̤ɽޤ' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_LABEL', '̾ [ 桼̾ ]' );

// labels of userlists, showusers
define( '_MD_XOONIPS_USERLIST_TITLE', '桼' );
define( '_MD_XOONIPS_USERLIST_EXPLANATION', '桼̾򥯥åȳƥ桼ξɽޤ' );

define( '_MD_XOONIPS_SHOW_USER_TITLE', '桼' );
define( '_MD_XOONIPS_SEND_MESSAGE', 'å' );
define( '_MD_XOONIPS_SHOW_CV_LABEL', 'ά' );
define( '_MD_XOONIPS_SHOW_PUBILICATION_LIST', 'ӥꥹ' );
define( '_MD_XOONIPS_SHOW_BACKTOLIST_LABEL', '' );
define( '_MD_XOONIPS_VIEW_USER_ACCOUNT', 'ȳǧ' );
define( '_MD_XOONIPS_EDIT_LISTS', 'Խ' );
define( '_MD_XOONIPS_ORDER_CHANGE', 'ɽѹ' );

define( '_MD_XOONIPS_UPLOAD_MAX_FILESIZE', 'ե륵:' );
define( '_MD_XOONIPS_UPLOAD_ERR_OK', 'åץ' );
define( '_MD_XOONIPS_UPLOAD_ERR_INI_SIZE', 'ե륵礭ޤ( upload_max_filesize )' );
define( '_MD_XOONIPS_UPLOAD_ERR_FORM_SIZE', 'ե륵礭ޤ( MAX_FILE_SIZE )' );
define( '_MD_XOONIPS_UPLOAD_ERR_PARTIAL', 'եΰåפޤǤ' );
define( '_MD_XOONIPS_UPLOAD_ERR_NO_FILE', 'եϥåץɤޤǤ' );
define( '_MD_XOONIPS_UPLOAD_ERR_NO_TMP_DIR', 'ƥݥեդޤ' );
define( '_MD_XOONIPS_UPLOAD_ERR_CANT_WRITE', 'ǥ˽񤭹߽ޤǤ' );

// labels for edit curriculum vitae, publication list
define( '_MD_XOONIPS_EDIT_CV_TITLE', 'άԽ' );
define( '_MD_XOONIPS_EDIT_CURRICULUM_VITAE', 'άԽ' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_LABEL', 'άɲ' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_WARNING', 'ܤϤƤ' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_FROM', 'From' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_TO', 'To' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_TITLE', '' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE', 'ɲ' );
define( '_MD_XOONIPS_MODIFY_CURRICULUM_VITAE_LABEL', 'άԽ' );
define( '_MD_XOONIPS_NO_CURRICULUM_VITAE_DATA', 'άǡϿƤޤ' );
define( "_MD_XOONIPS_CURRICULUM_VITAE_BUTTON_EDIT", "ѹ");
define( '_MD_XOONIPS_CURRICULUM_VITAE_CHECK_INFO', '桼' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_INSERT', 'άǡɲäޤ' );
define( '_MD_XOONIPS_NO_PUBLICATION_ITEM_DATA', 'ӥꥹȤ˥ƥबϿƤޤ' );
define( '_MD_XOONIPS_PUBLICATION_ITEM_CHANGE', 'ɽѹ' );
define( '_MD_XOONIPS_PUBLICATION_ITEM_INSERT', 'ӥꥹȤԽƤޤ' );

define( '_MD_XOONIPS_RANKING_UP', '' );
define( '_MD_XOONIPS_RANKING_DOWN', '' );
define( '_MD_XOONIPS_RANKING_NUM_ROWS_1', 'ƥ󥭥󥰤ξ' );
define( '_MD_XOONIPS_RANKING_NUM_ROWS_2', 'ɽޤ' );
define( '_MD_XOONIPS_RANKING_DAYS_1', '' );
define( '_MD_XOONIPS_RANKING_DAYS_2', '֤ΥǡΤߤ󥭥оݤȤޤ<br />λONˤ硤ͥեͤϥ󥭥󥰤ȿǤޤ' );

define( '_MD_XOONIPS_RANKING_WHAT_DELETING_LOG_IS', ' õȥ󥭥󥰤ꥢޤ<br />򤱤ˤϡõǽͥեΥɡåץɤԤäƤ' );
define( '_MD_XOONIPS_RANKING_FILE_CONFIG_EXPLAIN', 'ͤΥåץɡɤԤޤ' );
define( '_MD_XOONIPS_RANKING_DOWNLOAD_FILE', '' );
define( '_MD_XOONIPS_RANKING_UPLOAD_FILE', 'åץ' );
define( '_MD_XOONIPS_RANKING_CLEAR', 'ꥢ' );

define( '_MD_XOONIPS_RANKING_LABEL', '󥭥ѥ֥å' );
define( '_MD_XOONIPS_RANKING_NEW_LABEL', '󥭥ѥ֥å' );
define( '_MD_XOONIPS_RANKING_CHECK_RANKING_LABEL', 'ɽ󥭥󥰤򤷤Ƥ(ʣå)' );
define( '_MD_XOONIPS_RANKING_LOCKED', '߽ǤԤäƤȥ饤Ƥ' );

define("_MI_XOONIPS_RANKING_CONFIG", "󥭥"); 
define("_MI_XOONIPS_RANKING_FILE_CONFIG", "󥭥󥰽ץե"); 
define("_MD_XOONIPS_RANKING_VISIBLE", "ɽ"); 
define("_MD_XOONIPS_RANKING_NAME", "ɽ"); 

define("_MD_XOONIPS_RANKING_DOWNLOAD_LABEL", "ɤե̾"); 
define("_MD_XOONIPS_RANKING_UPLOAD_LABEL", "åץɤե"); 
define("_MD_XOONIPS_RANKING_CLEAR_SOME_LABEL", "%s  %s νͤäƤޤ"); 
define("_MD_XOONIPS_RANKING_CLEAR_EMPTY_LABEL", "ͤϤޤ"); 
define("_MD_XOONIPS_RANKING_CLEAR_LABEL", "ͤΥꥢ"); 

// admin/itemtype_order.php
define("_MD_XOONIPS_ITEMTYPE_CONFIGURATION_LABEL", "ƥॿ");
define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_LABEL", "ƥॿɽѹ");
define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_EXPLAIN", "ɽ1ʾꤷƤ");

define("_MD_XOONIPS_SU_TITLE", "suγ");
define("_MD_XOONIPS_SU_TARGET_USER", "Ȥڤؤ");
define("_MD_XOONIPS_SU_ADMIN_PASSWORD", "ʤΥѥ");
define("_MD_XOONIPS_SU_OK", "OK");
define("_MD_XOONIPS_SU_CANNOT_LOGOUT", "ȤsuλƤ");

define("_MD_XOONIPS_SU_START", "ȤڤؤƤޤ");
define("_MD_XOONIPS_SU_FAIL", "ѥɤۤʤޤ");
define("_MD_XOONIPS_SU_END", "Ԥޤ");
define("_MD_XOONIPS_SU_EXPLAIN", "Ū¾桼ΥȤǺȤ뤳ȤǤޤ");

?>
